.. -*- coding: utf-8 -*-

=============================
Manual Installation of PyBill
=============================

The source code of PyBill can be downloaded from `Logilab ftp server`_ or from
`Logilab mercurial repository`_\ . 

In the root directory of the source code (``pybill`` directory), you will find a
``setup.py`` file that allows you to perform several operations with
`setuptools`. For example, ``python setup.py install`` allows you to manually 
install PyBill. See ``python setup.py --help`` for more details.

Please be aware that the dependencies of PyBill must be installed in order to
properly run PyBill.

.. _`Logilab ftp server`: http://ftp.logilab.org/pub/pybill/
.. _`Logilab mercurial repository`: http://www.logilab.org/src/pybill
